package hu.prioritasdemo.ejb;

import javax.annotation.Resource;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;
import org.apache.log4j.Logger;

/**
 *
 * @author Kerekes András
 */
@Stateless
public class SMSToQueueSessionBean implements SMSToQueueSessionBeanLocal {
    @Resource(mappedName = "jms/SMSQueue")
    private Queue sMSQueue;
    @Resource(mappedName = "jms/SMSQueueFactory")
    private ConnectionFactory sMSQueueFactory;
    
    private static Logger log = Logger.getLogger(SMSToQueueSessionBean.class);    
    

    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRES_NEW)    
    public void sendJMSMessageToSMSQueue(String uzenet, int prioritas) throws JMSException {
        Connection connection = null;
        Session session = null;
        try {
            connection = sMSQueueFactory.createConnection();
            session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
            MessageProducer messageProducer = session.createProducer(sMSQueue);
            messageProducer.setPriority(prioritas);
            
            TextMessage tm = session.createTextMessage();          
            tm.setText(uzenet);  
            
            messageProducer.send(tm);
            
            messageProducer.close();            
        } finally {
            if (session != null) {
                try {
                    session.close();
                } catch (JMSException e) {
                    log.fatal(e);
                }
            }
            if (connection != null) {
                connection.close();
            }
        }
    }
    
}
